@@ -17,11 +17,13 @@ use constant CannotCloneVoiceAuthorizations                    => "91541";
 use constant CannotHoldInEscrow                                => "91560";
 use constant CannotPartiallyRefundEscrowedTransaction          => "91563";
 use constant CannotRefundCredit                                => "91505";
+use constant CannotRefundSettlingTransaction                   => "91574";
 use constant CannotRefundUnlessSettled                         => "91506";
 use constant CannotRefundWithPendingMerchantAccount            => "91559";
 use constant CannotRefundWithSuspendedMerchantAccount          => "91538";
 use constant CannotReleaseFromEscrow                           => "91561";
 use constant CannotSubmitForSettlement                         => "91507";
+use constant CannotSimulateSettlement                          => "91575";
 use constant ChannelIsTooLong                                  => "91550";
 use constant CreditCardIsRequired                              => "91508";
 use constant CustomFieldIsInvalid                              => "91526";
@@ -35,12 +37,18 @@ use constant MerchantAccountDoesNotSupportRefunds              => "91547";
 use constant MerchantAccountIdIsInvalid                        => "91513";
 use constant MerchantAccountIsSuspended                        => "91514";
 use constant OrderIdIsTooLong                                  => "91501";
+use constant PaymentInstrumentNotSupportedByMerchantAccount    => "91577";
 use constant PaymentMethodConflict                             => "91515";
 use constant PaymentMethodConflictWithVenmoSDK                 => "91549";
 use constant PaymentMethodDoesNotBelongToCustomer              => "91516";
 use constant PaymentMethodDoesNotBelongToSubscription          => "91527";
+use constant PaymentMethodNonceCardTypeIsNotAccepted           => "91567";
+use constant PaymentMethodNonceConsumed                        => "91564";
+use constant PaymentMethodNonceLocked                          => "91566";
+use constant PaymentMethodNonceUnknown                         => "91565";
 use constant PaymentMethodTokenCardTypeIsNotAccepted           => "91517";
 use constant PaymentMethodTokenIsInvalid                       => "91518";
+use constant PayPalNotEnabled                                  => "91576";
 use constant ProcessorAuthorizationCodeCannotBeSet             => "91519";
 use constant ProcessorAuthorizationCodeIsInvalid               => "81520";
 use constant ProcessorDoesNotSupportCredits                    => "91546";
@@ -62,6 +70,9 @@ use constant SubscriptionStatusMustBePastDue                   => "91531";
 use constant TaxAmountCannotBeNegative                         => "81534";
 use constant TaxAmountFormatIsInvalid                          => "81535";
 use constant TaxAmountIsTooLarge                               => "81536";
+use constant ThreeDSecureAuthenticationFailed                  => "81571";
+use constant ThreeDSecureTokenIsInvalid                        => "91568";
+use constant ThreeDSecureTransactionDataDoesntMatchVerify      => "91570";
 use constant TypeIsInvalid                                     => "91523";
 use constant TypeIsRequired                                    => "91524";
 use constant UnsupportedVoiceAuthorization                     => "91539";
