@@ -9,6 +9,11 @@ sub create {
   $class->gateway->payment_method->create($params);
 }
 
+sub update {
+  my ($class, $token, $params) = @_;
+  $class->gateway->payment_method->update($token, $params);
+}
+
 sub delete {
   my ($class, $token) = @_;
   $class->gateway->payment_method->delete($token);
